diff --git a/core/modules/simpletest/tests/Drupal/simpletest/Tests/WebTestBaseTest.php b/core/modules/simpletest/tests/Drupal/simpletest/Tests/WebTestBaseTest.php
index bbfdadd..8617867 100644
--- a/core/modules/simpletest/tests/Drupal/simpletest/Tests/WebTestBaseTest.php
+++ b/core/modules/simpletest/tests/Drupal/simpletest/Tests/WebTestBaseTest.php
@@ -66,11 +66,11 @@ public function testAssertFieldByName($filename, $name, $value, $expected) {
$web_test = $this->getMockBuilder('Drupal\simpletest\WebTestBase')
->disableOriginalConstructor()
- ->setMethods(array('assertTrue', 'drupalGetContent', 'pass'))
+ ->setMethods(array('getRawContent', 'assertTrue', 'pass'))
->getMock();
$web_test->expects($this->any())
- ->method('drupalGetContent')
+ ->method('getRawContent')
->will($this->returnValue($content));
$web_test->expects($this->once())
diff --git a/core/modules/simpletest/lib/Drupal/simpletest/WebTestBase.php b/core/modules/simpletest/lib/Drupal/simpletest/WebTestBase.php
index 77d0109..ebaee95 100644
--- a/core/modules/simpletest/lib/Drupal/simpletest/WebTestBase.php
+++ b/core/modules/simpletest/lib/Drupal/simpletest/WebTestBase.php
@@ -1276,11 +1276,11 @@ protected function curlExec($curl_options, $redirect = FALSE) {
'!method' => !empty($curl_options[CURLOPT_NOBODY]) ? 'HEAD' : (empty($curl_options[CURLOPT_POSTFIELDS]) ? 'GET' : 'POST'),
'@url' => isset($original_url) ? $original_url : $url,
'@status' => $status,
- '!length' => format_size(strlen($this->drupalGetContent()))
+ '!length' => format_size(strlen($this->getRawContent()))
);
$message = String::format('!method @url returned @status (!length).', $message_vars);
- $this->assertTrue($this->drupalGetContent() !== FALSE, $message, 'Browser');
- return $this->drupalGetContent();
+ $this->assertTrue($this->getRawContent() !== FALSE, $message, 'Browser');
+ return $this->getRawContent();
}
/**
@@ -1371,7 +1371,7 @@ protected function isInChildSite() {
* "name: value".
*
* @return
* The retrieved HTML string, also available as $this->drupalGetContent()
*/
protected function drupalGet($path, array $options = array(), array $headers = array()) {
$options['absolute'] = TRUE;
@@ -1953,7 +1953,7 @@ protected function cronRun() {
* Either the new page content or FALSE.
*/
protected function checkForMetaRefresh() {
- if (strpos($this->drupalGetContent(), 'parse()) {
+ if (strpos($this->getRawContent(), 'parse()) {
$refresh = $this->xpath('//meta[@http-equiv="Refresh"]');
if (!empty($refresh)) {
// Parse the content attribute of the meta tag for the format:
@@ -1978,7 +1978,7 @@ protected function checkForMetaRefresh() {
* "name: value".
*
* @return
* The retrieved headers, also available as $this->drupalGetContent()
*/
protected function drupalHead($path, array $options = array(), array $headers = array()) {
$options['absolute'] = TRUE;
@@ -1371,7 +1371,7 @@ protected function isInChildSite() {
*
* @return
- * The retrieved HTML string, also available as $this->drupalGetContent()
+ * The retrieved HTML string, also available as $this->getRawContent()
*/
protected function drupalGet($path, array $options = array(), array $headers = array()) {
@@ -1978,7 +1978,7 @@ protected function checkForMetaRefresh() {
*
* @return
- * The retrieved headers, also available as $this->drupalGetContent()
+ * The retrieved headers, also available as $this->getRawContent()
*/
protected function drupalHead($path, array $options = array(), array $headers = array()) {